# eolearn.mask subpackage

The subpackage is used for masking of data and calculation of cloud masks.

For more information on the package content, visit [readthedocs](https://eo-learn.readthedocs.io/en/latest/eolearn.mask.html).
